@@ -98,12 +98,14 @@ void ReadAPMDevice( )		/* FreeBSD version */
 {
 	int fd;
 	struct apm_info info;
+	memset(&info, 0, sizeof(info));
 	if ((fd = open(apm_device_file, O_RDONLY)) == -1) {
 		error_handle(1, "");
 		return;
 	}
 	if (ioctl(fd, APMIO_GETINFO, &info) == -1) {
 		error_handle(4, "");
+		close(fd);
 		return;
 	}
 	close(fd);
@@ -138,12 +140,14 @@ void ReadAPMDevice( )		/* NetBSD version */
 {
 	int fd;
 	struct apm_power_info info;
+	memset(&info, 0, sizeof(info));
 	if ((fd = open(apm_device_file, O_RDONLY)) == -1) {
 		error_handle(1, "");
 		return;
 	}
 	if (ioctl(fd, APM_IOC_GETPOWER, &info) == -1) {
 		error_handle(4, "");
+		close(fd);
 		return;
 	}
 	close(fd);
