@@ -274,7 +274,10 @@ void initializeWindow(int argc, char** argv,
 #endif
 
 	backgroundXpm.attributes.valuemask |= 
-		(XpmReturnPixels | XpmReturnExtensions);
+		(XpmReturnPixels | XpmReturnExtensions
+		| XpmExactColors | XpmCloseness);
+	backgroundXpm.attributes.exactColors = False;
+	backgroundXpm.attributes.closeness = 65536;
 	background = embossed ? background_in : background_out;
 	if ( state.color_depth == 8 ) {
 		/* degrade the background */
@@ -571,7 +574,10 @@ void initializeWindow(int argc, char** argv,
 #endif
 
 	alphabetXpm.attributes.valuemask |= 
-		(XpmReturnPixels | XpmReturnExtensions);
+		(XpmReturnPixels | XpmReturnExtensions
+		| XpmExactColors | XpmCloseness);
+	alphabetXpm.attributes.exactColors = False;
+	alphabetXpm.attributes.closeness = 65536;
 	status = XpmCreatePixmapFromData(
 		mainDisplay,            	/* display */
 		Root,             		/* window */
